Struct ZwpTabletSeatV1
pub struct ZwpTabletSeatV1 { /* private fields */ }wayland and Linux only.Expand description
controller object for graphic tablet devices of a seat
An object that provides access to the graphics tablets available on this seat. After binding to this interface, the compositor sends a set of wp_tablet_seat.tablet_added and wp_tablet_seat.tool_added events.
See also the Request enum for this interface.
Implementations
impl ZwpTabletSeatV1
impl ZwpTabletSeatV1
pub fn tablet_added(&self, id: &ZwpTabletV1)
pub fn tablet_added(&self, id: &ZwpTabletV1)
new device notification
This event is sent whenever a new tablet becomes available on this seat. This event only provides the object id of the tablet, any static information about the tablet (device name, vid/pid, etc.) is sent through the wp_tablet interface.
pub fn tool_added(&self, id: &ZwpTabletToolV1)
pub fn tool_added(&self, id: &ZwpTabletToolV1)
a new tool has been used with a tablet
This event is sent whenever a tool that has not previously been used with a tablet comes into use. This event only provides the object id of the tool; any static information about the tool (capabilities, type, etc.) is sent through the wp_tablet_tool interface.